@@ -4,7 +4,7 @@ from lung.controllers._predictive_pid import PredictivePID
 from lung.controllers._original_pid import OriginalPID
 from lung.controllers._learned_bias import LearnedBias
 from lung.controllers._predictive_bias_pi import PredictiveBiasPI
-from lung.controllers._predictive_bias_const_pi import PredictiveBiasConstPI
+from lung.controllers._ada_pi import AdaPI
 
 __all__ = [
     "Lookahead",
@@ -13,5 +13,5 @@ __all__ = [
     "OriginalPID",
     "LearnedBias",
     "PredictiveBiasPI",
-    "PredictiveBiasConstPI",
+    "AdaPI"
 ]
