@@ -18,7 +18,7 @@ class Lookahead(Controller):
         u_in = 0
         for i in range(self.lookahead_steps):
             lookahead_state = self.forecast_model.predict(i)
-            u_in = controller_copy.feed(lookahead_state, cycle_phase + i * dt)
+            u_in, _ = controller_copy.feed(lookahead_state, cycle_phase + i * dt)
 
         self.base_controller.feed(state, cycle_phase)
         return (u_in, self.u_out(cycle_phase))
