@@ -3,7 +3,7 @@ from lung.controllers.core import Controller
 
 # generic PID controller
 class PID(Controller):
-    def __init__(self, K, RC=0.5, **kwargs):
+    def __init__(self, K=[3, 4, 0], RC=0.5, **kwargs):
         # controller coeffs
         self.K_P, self.K_I, self.K_D = K
 
