@@ -6,14 +6,13 @@ from lung.controllers._lookahead import Lookahead
 
 
 class PredictiveBiasPI(Controller):
-    def __init__(self, p, i, RC, lookahead_steps=15, bias_lr=0.01, **kwargs):
+    def __init__(self, p=0.5, i=2.5, RC=0.06, lookahead_steps=15, bias_lr=0.01, **kwargs):
         # controller coeffs
         self.bias_lr = bias_lr
         self.bias = 0
-        self.waveform = waveform
         self.storage = 3
         self.forecaster = LinearForecaster(self.storage)
-        self.pid = PID(self.waveform, [p, i, 0.0], RC=RC)
+        self.pid = PID(K=[p, i, 0.0], RC=RC, waveform=self.waveform)
         self.base_controller = Lookahead(self.forecaster, self.pid, lookahead_steps)
 
     def feed(self, state, t):
@@ -21,5 +20,5 @@ class PredictiveBiasPI(Controller):
         cycle_phase = self.cycle_phase(t)
 
         self.bias = self.bias + np.sign(err) * self.bias_lr
-        base_control = self.base_controller.feed(state, cycle_phase)
+        base_control, _ = self.base_controller.feed(state, cycle_phase)
         return (base_control + self.bias, self.u_out(cycle_phase))
