@@ -18,6 +18,8 @@ class PredictivePID(Controller):
 
     def feed(self, state, t):
         dt = self.dt(t)
+        cycle_phase = self.cycle_phase(t)
+
         self.errs[0] = self.waveform.at(t) - state
         self.errs = np.roll(self.errs, -1)
         self.bias += np.sign(np.average(self.errs)) * self.bias_lr
@@ -32,11 +34,11 @@ class PredictivePID(Controller):
             for j in range(self.hallucination_length)
         ]
 
-        if t < 0.1:
+        if cycle_phase < 0.1:
             u = np.sum(self.errs) + self.bias
         else:
             new_av = (np.sum(self.errs) + np.sum(hallucinated_errors)) * (
                 self.storage / (self.storage + len(hallucinated_errors))
             )
             u = new_av + self.bias
-        return (u, self.u_out(t))
+        return (u, self.u_out(cycle_phase))
