@@ -7,7 +7,7 @@ from lung.environments.core import Environment
 # https://github.com/CohenLabPrinceton/Ventilator-Dev/blob/master/sandbox/HOWTO_RunController.ipynb
 # https://github.com/CohenLabPrinceton/Ventilator-Dev/blob/master/vent/controller/control_module.py
 class DemoLung(Environment):
-    def __init__(self, leak, peep_valve, PC, RP):
+    def __init__(self, leak=False, peep_valve=5, PC=40, RP=1):
         # dynamics hyperparameters
         self.max_volume = 6  ### seems unused from code
         self.min_volume = 1.5
